@@ -1,11 +1,15 @@
 package Bread::Board::BlockInjection;
+BEGIN {
+  $Bread::Board::BlockInjection::AUTHORITY = 'cpan:STEVAN';
+}
+{
+  $Bread::Board::BlockInjection::VERSION = '0.22';
+}
 use Moose;
 
-our $VERSION   = '0.21';
-our $AUTHORITY = 'cpan:STEVAN';
-
 with 'Bread::Board::Service::WithParameters',
-     'Bread::Board::Service::WithDependencies';
+     'Bread::Board::Service::WithDependencies',
+     'Bread::Board::Service::WithClass';
 
 has 'block' => (
     is       => 'rw',
@@ -13,16 +17,9 @@ has 'block' => (
     required => 1,
 );
 
-has 'class' => (
-    is        => 'rw',
-    isa       => 'Str',
-    predicate => 'has_class'
-);
-
 
 sub get {
     my $self = shift;
-    Class::MOP::load_class($self->class) if $self->has_class;
     $self->block->($self)
 }
 
@@ -30,7 +27,7 @@ __PACKAGE__->meta->make_immutable;
 
 no Moose; 1;
 
-__END__
+
 
 =pod
 
@@ -38,6 +35,10 @@ __END__
 
 Bread::Board::BlockInjection
 
+=head1 VERSION
+
+version 0.22
+
 =head1 DESCRIPTION
 
 =head1 METHODS
@@ -75,4 +76,19 @@ L<http://www.iinteractive.com>
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Stevan Little <stevan@iinteractive.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Infinity Interactive.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
+
+
+__END__
+
