@@ -1,13 +1,16 @@
 package Bread::Board::ConstructorInjection;
+BEGIN {
+  $Bread::Board::ConstructorInjection::AUTHORITY = 'cpan:STEVAN';
+}
+{
+  $Bread::Board::ConstructorInjection::VERSION = '0.22';
+}
 use Moose;
 
 use Try::Tiny;
 
 use Bread::Board::Types;
 
-our $VERSION   = '0.21';
-our $AUTHORITY = 'cpan:STEVAN';
-
 with 'Bread::Board::Service::WithClass',
      'Bread::Board::Service::WithParameters',
      'Bread::Board::Service::WithDependencies';
@@ -19,6 +22,8 @@ has 'constructor_name' => (
     builder  => '_build_constructor_name',
 );
 
+has '+class' => (required => 1);
+
 sub _build_constructor_name {
     my $self = shift;
 
@@ -36,7 +41,7 @@ __PACKAGE__->meta->make_immutable;
 
 no Moose; 1;
 
-__END__
+
 
 =pod
 
@@ -44,6 +49,10 @@ __END__
 
 Bread::Board::ConstructorInjection
 
+=head1 VERSION
+
+version 0.22
+
 =head1 DESCRIPTION
 
 =head1 METHODS
@@ -73,4 +82,19 @@ L<http://www.iinteractive.com>
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Stevan Little <stevan@iinteractive.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Infinity Interactive.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
+
+
+__END__
+
