@@ -1,11 +1,14 @@
 package Bread::Board::Dependency;
+BEGIN {
+  $Bread::Board::Dependency::AUTHORITY = 'cpan:STEVAN';
+}
+{
+  $Bread::Board::Dependency::VERSION = '0.22';
+}
 use Moose;
 
 use Bread::Board::Service;
 
-our $VERSION   = '0.21';
-our $AUTHORITY = 'cpan:STEVAN';
-
 with 'Bread::Board::Traversable';
 
 has 'service_path' => (
@@ -49,7 +52,7 @@ __PACKAGE__->meta->make_immutable;
 
 no Moose; 1;
 
-__END__
+
 
 =pod
 
@@ -57,6 +60,10 @@ __END__
 
 Bread::Board::Dependency
 
+=head1 VERSION
+
+version 0.22
+
 =head1 DESCRIPTION
 
 =head1 METHODS
@@ -100,4 +107,19 @@ L<http://www.iinteractive.com>
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Stevan Little <stevan@iinteractive.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Infinity Interactive.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
+
+
+__END__
+
