@@ -1,9 +1,12 @@
 package Bread::Board::Dumper;
+BEGIN {
+  $Bread::Board::Dumper::AUTHORITY = 'cpan:STEVAN';
+}
+{
+  $Bread::Board::Dumper::VERSION = '0.22';
+}
 use Moose;
 
-our $VERSION   = '0.21';
-our $AUTHORITY = 'cpan:STEVAN';
-
 sub dump {
     my ($self, $thing, $indent) = @_;
 
@@ -44,7 +47,7 @@ __PACKAGE__->meta->make_immutable;
 
 no Moose; 1;
 
-__END__
+
 
 =pod
 
@@ -52,6 +55,10 @@ __END__
 
 Bread::Board::Dumper
 
+=head1 VERSION
+
+version 0.22
+
 =head1 SYNOPSIS
 
   use Bread::Board::Dumper;
@@ -94,4 +101,19 @@ L<http://www.iinteractive.com>
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Stevan Little <stevan@iinteractive.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Infinity Interactive.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
+
+
+__END__
+
