@@ -1,11 +1,15 @@
 package Bread::Board::GraphViz::App;
+BEGIN {
+  $Bread::Board::GraphViz::App::AUTHORITY = 'cpan:STEVAN';
+}
+{
+  $Bread::Board::GraphViz::App::VERSION = '0.22';
+}
 use Moose;
+# ABSTRACT: display a L<Bread::Board>'s dependency graph
 
 use Bread::Board::GraphViz;
 
-our $AUTHORITY = 'cpan:STEVAN';
-our $VERSION   = '0.21';
-
 with 'MooseX::Runnable';
 
 sub run {
@@ -29,7 +33,7 @@ __PACKAGE__->meta->make_immutable;
 
 no Moose; 1;
 
-__END__
+
 
 =pod
 
@@ -37,6 +41,10 @@ __END__
 
 Bread::Board::GraphViz::App - display a L<Bread::Board>'s dependency graph
 
+=head1 VERSION
+
+version 0.22
+
 =head1 SYNOPSIS
 
 See L<visualize-breadboard.pl>.
@@ -60,4 +68,19 @@ L<http://www.iinteractive.com>
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Stevan Little <stevan@iinteractive.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Infinity Interactive.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
+
+
+__END__
+
