@@ -1,13 +1,16 @@
 package Bread::Board::LifeCycle::Singleton;
+BEGIN {
+  $Bread::Board::LifeCycle::Singleton::AUTHORITY = 'cpan:STEVAN';
+}
+{
+  $Bread::Board::LifeCycle::Singleton::VERSION = '0.22';
+}
 use Moose::Role;
 
 use Try::Tiny;
 
 with 'Bread::Board::LifeCycle';
 
-our $VERSION   = '0.21';
-our $AUTHORITY = 'cpan:STEVAN';
-
 has 'instance' => (
     traits    => [ 'NoClone' ],
     is        => 'rw',
@@ -59,7 +62,7 @@ around 'get' => sub {
 
 no Moose::Role; 1;
 
-__END__
+
 
 =pod
 
@@ -67,6 +70,10 @@ __END__
 
 Bread::Board::LifeCycle::Singleton
 
+=head1 VERSION
+
+version 0.22
+
 =head1 DESCRIPTION
 
 =head1 METHODS
@@ -102,4 +109,19 @@ L<http://www.iinteractive.com>
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Stevan Little <stevan@iinteractive.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Infinity Interactive.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
+
+
+__END__
+
