@@ -1,11 +1,14 @@
 package Bread::Board::LifeCycle::Singleton::WithParameters;
+BEGIN {
+  $Bread::Board::LifeCycle::Singleton::WithParameters::AUTHORITY = 'cpan:STEVAN';
+}
+{
+  $Bread::Board::LifeCycle::Singleton::WithParameters::VERSION = '0.22';
+}
 use Moose::Role;
 
 with 'Bread::Board::LifeCycle';
 
-our $VERSION   = '0.21';
-our $AUTHORITY = 'cpan:STEVAN';
-
 has 'instances' => (
     traits    => [ 'Hash', 'NoClone' ],
     is        => 'rw',
@@ -49,7 +52,7 @@ sub generate_instance_key {
 
 no Moose::Role; 1;
 
-__END__
+
 
 =pod
 
@@ -57,6 +60,10 @@ __END__
 
 Bread::Board::LifeCycle::Singleton::WithParameters
 
+=head1 VERSION
+
+version 0.22
+
 =head1 DESCRIPTION
 
 =head1 METHODS
@@ -92,4 +99,21 @@ L<http://www.iinteractive.com>
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
+=for Pod::Coverage generate_instance_key
+
+=head1 AUTHOR
+
+Stevan Little <stevan@iinteractive.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Infinity Interactive.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
+
+
+__END__
+
