@@ -1,11 +1,14 @@
 package Bread::Board::Service::Alias;
+BEGIN {
+  $Bread::Board::Service::Alias::AUTHORITY = 'cpan:STEVAN';
+}
+{
+  $Bread::Board::Service::Alias::VERSION = '0.22';
+}
 use Moose;
 
 use Try::Tiny;
 
-our $VERSION   = '0.21';
-our $AUTHORITY = 'cpan:STEVAN';
-
 has aliased_from_path => (
     is  => 'ro',
     isa => 'Str',
@@ -40,4 +43,30 @@ __PACKAGE__->meta->make_immutable;
 
 no Moose; 1;
 
+
+
+=pod
+
+=head1 NAME
+
+Bread::Board::Service::Alias
+
+=head1 VERSION
+
+version 0.22
+
+=head1 AUTHOR
+
+Stevan Little <stevan@iinteractive.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Infinity Interactive.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
+
 __END__
