@@ -1,9 +1,12 @@
 package Bread::Board::Service::Deferred;
+BEGIN {
+  $Bread::Board::Service::Deferred::AUTHORITY = 'cpan:STEVAN';
+}
+{
+  $Bread::Board::Service::Deferred::VERSION = '0.22';
+}
 use Moose ();
 
-our $VERSION   = '0.21';
-our $AUTHORITY = 'cpan:STEVAN';
-
 use overload
     # cover your basic operatins ...
     'bool' => sub { 1 },
@@ -83,7 +86,7 @@ sub AUTOLOAD {
 
 1;
 
-__END__
+
 
 =pod
 
@@ -91,6 +94,10 @@ __END__
 
 Bread::Board::Service::Deferred
 
+=head1 VERSION
+
+version 0.22
+
 =head1 DESCRIPTION
 
 No user servicable parts. Read the source if you are interested.
@@ -114,4 +121,24 @@ L<http://www.iinteractive.com>
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
+=for Pod::Coverage can
+isa
+meta
+new
+
+=head1 AUTHOR
+
+Stevan Little <stevan@iinteractive.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Infinity Interactive.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
+
+
+__END__
+
