@@ -1,10 +1,13 @@
 package Bread::Board::Service::Inferred;
+BEGIN {
+  $Bread::Board::Service::Inferred::AUTHORITY = 'cpan:STEVAN';
+}
+{
+  $Bread::Board::Service::Inferred::VERSION = '0.22';
+}
 use Moose;
 use Moose::Util::TypeConstraints 'find_type_constraint';
 
-our $VERSION   = '0.21';
-our $AUTHORITY = 'cpan:STEVAN';
-
 use Try::Tiny;
 use Bread::Board::Types;
 use Bread::Board::ConstructorInjection;
@@ -212,7 +215,7 @@ __PACKAGE__->meta->make_immutable;
 
 no Moose; 1;
 
-__END__
+
 
 =pod
 
@@ -220,12 +223,24 @@ __END__
 
 Bread::Board::Service::Inferred
 
+=head1 VERSION
+
+version 0.22
+
 =head1 DESCRIPTION
 
 CAUTION, EXPERIMENTAL FEATURE.
 
 Docs to come, as well as refactoring.
 
+=head1 METHODS
+
+=over 4
+
+=item B<infer_service>
+
+=back
+
 =head1 BUGS
 
 All complex software has bugs lurking in it, and this module is no
@@ -245,4 +260,19 @@ L<http://www.iinteractive.com>
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Stevan Little <stevan@iinteractive.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Infinity Interactive.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
+
+
+__END__
+
