@@ -1,26 +1,31 @@
 package Bread::Board::Service::WithClass;
+BEGIN {
+  $Bread::Board::Service::WithClass::AUTHORITY = 'cpan:STEVAN';
+}
+{
+  $Bread::Board::Service::WithClass::VERSION = '0.22';
+}
 use Moose::Role;
 
 use Bread::Board::Types;
 
-our $VERSION   = '0.21';
-our $AUTHORITY = 'cpan:STEVAN';
-
 with 'Bread::Board::Service';
 
 has 'class' => (
-    is       => 'rw',
-    isa      => 'Str',
-    required => 1,
+    is        => 'rw',
+    isa       => 'Str',
+    predicate => 'has_class',
 );
 
 before 'get' => sub {
-    Class::MOP::load_class((shift)->class)
+    my $self = shift;
+    Class::MOP::load_class($self->class)
+        if $self->has_class;
 };
 
 no Moose::Role; 1;
 
-__END__
+
 
 =pod
 
@@ -28,6 +33,10 @@ __END__
 
 Bread::Board::Service::WithClass
 
+=head1 VERSION
+
+version 0.22
+
 =head1 DESCRIPTION
 
 =head1 METHODS
@@ -59,4 +68,19 @@ L<http://www.iinteractive.com>
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Stevan Little <stevan@iinteractive.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Infinity Interactive.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
+
+
+__END__
+
