@@ -1,4 +1,10 @@
 package Bread::Board::Service::WithDependencies;
+BEGIN {
+  $Bread::Board::Service::WithDependencies::AUTHORITY = 'cpan:STEVAN';
+}
+{
+  $Bread::Board::Service::WithDependencies::VERSION = '0.22';
+}
 use Moose::Role;
 
 use Try::Tiny;
@@ -7,9 +13,6 @@ use Bread::Board::Types;
 use Bread::Board::Service::Deferred;
 use Bread::Board::Service::Deferred::Thunk;
 
-our $VERSION   = '0.21';
-our $AUTHORITY = 'cpan:STEVAN';
-
 with 'Bread::Board::Service';
 
 has 'dependencies' => (
@@ -103,7 +106,7 @@ sub resolve_dependencies {
 
 no Moose::Role; 1;
 
-__END__
+
 
 =pod
 
@@ -111,6 +114,10 @@ __END__
 
 Bread::Board::Service::WithDependencies
 
+=head1 VERSION
+
+version 0.22
+
 =head1 DESCRIPTION
 
 =head1 METHODS
@@ -154,4 +161,19 @@ L<http://www.iinteractive.com>
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Stevan Little <stevan@iinteractive.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Infinity Interactive.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
+
+
+__END__
+
