@@ -1,15 +1,20 @@
 package Bread::Board::SetterInjection;
+BEGIN {
+  $Bread::Board::SetterInjection::AUTHORITY = 'cpan:STEVAN';
+}
+{
+  $Bread::Board::SetterInjection::VERSION = '0.22';
+}
 use Moose;
 
 use Bread::Board::Types;
 
-our $VERSION   = '0.21';
-our $AUTHORITY = 'cpan:STEVAN';
-
 with 'Bread::Board::Service::WithClass',
      'Bread::Board::Service::WithParameters',
      'Bread::Board::Service::WithDependencies';
 
+has '+class' => (required => 1);
+
 sub get {
     my $self = shift;
     my $o = $self->class->new;
@@ -21,7 +26,7 @@ __PACKAGE__->meta->make_immutable;
 
 no Moose; 1;
 
-__END__
+
 
 =pod
 
@@ -29,6 +34,10 @@ __END__
 
 Bread::Board::SetterInjection
 
+=head1 VERSION
+
+version 0.22
+
 =head1 DESCRIPTION
 
 =head1 METHODS
@@ -58,4 +67,19 @@ L<http://www.iinteractive.com>
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Stevan Little <stevan@iinteractive.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Infinity Interactive.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
+
+
+__END__
+
