@@ -1,9 +1,12 @@
 package Bread::Board::Traversable;
+BEGIN {
+  $Bread::Board::Traversable::AUTHORITY = 'cpan:STEVAN';
+}
+{
+  $Bread::Board::Traversable::VERSION = '0.22';
+}
 use Moose::Role;
 
-our $VERSION   = '0.21';
-our $AUTHORITY = 'cpan:STEVAN';
-
 with 'MooseX::Clone';
 
 has 'parent' => (
@@ -95,7 +98,7 @@ sub _get_container_or_service {
 
 no Moose::Role; 1;
 
-__END__
+
 
 =pod
 
@@ -103,6 +106,10 @@ __END__
 
 Bread::Board::Traversable
 
+=head1 VERSION
+
+version 0.22
+
 =head1 SYNOPSIS
 
 =head1 DESCRIPTION
@@ -142,4 +149,19 @@ L<http://www.iinteractive.com>
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Stevan Little <stevan@iinteractive.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Infinity Interactive.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
+
+
+__END__
+
